/* global Bdf,$$,Overlay,ID */

Bdf.Overlay = {};

Bdf.Overlay.showFqlEditor = function (xml, updateCallback) {
    var frameId = Bdf.generateId();
    var okId = Bdf.generateId();
    var supplementaryClasses = "global-overlay-FqlEditor";
    var jsonData = null;
    var isLoaded = false;
    var toBeInit = true;
    var overlayCallback = null;
    Overlay.start({
        header: Bdf.Loc.escape("_ title.selection.fqleditor"),
        content: Bdf.render("bdf:fqleditor", {
            frameId: frameId
        }),
        supplementaryClasses: {
            content: supplementaryClasses
        },
        footer: Bdf.render("bdf:overlay-footer", {
            submit: {
                type: "button",
                id: okId,
                locKey: '_ link.global.ok'
            }}),
        isWaiting: true,
        afterStart: function (overlayId, waitingCallback) {
            ID(frameId).addEventListener("load", function () {
                isLoaded = true;
                _initIframe(overlayId);
            });
            $.ajax({
                url: Bdf.URL + "selection",
                method: "POST",
                data: {
                    cmd: "FqlParser",
                    json: "fql",
                    xml: xml
                },
                dataType: Bdf.jsonDataType,
                success: function (data, textStatus) {
                    jsonData = data;
                    overlayCallback = waitingCallback;
                    _initIframe(overlayId);
                }
            });
        }
    });
    
    
    function _initIframe(overlayId) {
        if ((jsonData) && (isLoaded) && (toBeInit)) {
            toBeInit = false;
            overlayCallback();
            ID(frameId).contentWindow.FqlEditor.update(jsonData, overlayId);
            Overlay.addEscapeKeyHandler(ID(frameId).contentDocument);
            $$(okId).click(function () {
                let result = ID(frameId).contentWindow.FqlEditor.getResult();
                Overlay.end(overlayId, function () {
                    updateCallback(result);
                });
            });
        }
    }
};

Bdf.Overlay.showFicheEditor = function (corpus, id, options) {
    var frameId = Bdf.generateId();
    var supplementaryClasses = "global-overlay-FicheEditor";
    var isIdDefined;
    var changeDone = false;
    var page;
    var loadCallback;
    var doneCallback;
    var cancelCallback;
    if ((!id) || (id < 1)) {
        isIdDefined = false;
        id = null;
        page = "fiche-creation";
    } else {
        isIdDefined = true;
        page = "fiche-change";
    }
    if (options) {
        if (options.supplementaryClasses) {
            supplementaryClasses = supplementaryClasses  + " " + options.supplementaryClasses;
        }
        if (options.loadCallback) {
            loadCallback = options.loadCallback;
        }
        if (options.doneCallback) {
            doneCallback = options.doneCallback;
        }
        if (options.cancelCallback) {
            cancelCallback = options.cancelCallback;
        }
    }
    Overlay.start({
        content: Bdf.render("bdf:ficheeditor", {
            corpus: corpus,
            page: page,
            id: id,
            frameId: frameId
        }),
        supplementaryClasses: {
            content: supplementaryClasses
        },
        afterStart: function (overlayId) {
            $$(frameId).on("load", function (event) {
                try {
                    let iframeWindow = this.contentWindow;
                    let closeButton = iframeWindow.document.getElementById("button_overlay_close");
                    let addHandler = true;
                    if (closeButton) {
                        closeButton.addEventListener('click', function () {
                            Overlay.end(overlayId);
                        });
                        if ((closeButton.dataset.shortcutKey) && (closeButton.dataset.shortcutKey === "Escape")) {
                            addHandler = false;
                        }
                    }
                    if (addHandler) {
                        Overlay.addEscapeKeyHandler(this.contentDocument);
                    }
                    if (iframeWindow.RESULT_ITEM) {
                        changeDone = true;
                        if (!isIdDefined) {
                            id = iframeWindow.RESULT_ITEM.id;
                            isIdDefined = true;
                        }
                    }
                    if (loadCallback) {
                        loadCallback(iframeWindow);
                    }
                } catch(error) {
                    Bdf.log(error);
                }
            });
        },
        beforeEnd: function () {
            let iframe = ID(frameId);
            if (iframe) {
                try {
                    if (iframe.contentWindow.Bdf) {
                        return iframe.contentWindow.Bdf.confirmUnload();
                    }
                } catch(error) {
                    Bdf.log(error);
                }
            }
            return true;
        },
        afterEnd: function () {
            if (changeDone) {
                if (doneCallback) {
                    doneCallback(corpus, id);
                }
            } else if (cancelCallback) {
                cancelCallback();
            }
        }
    });
};
